.. ReliableStatistics documentation master file, created by
   sphinx-quickstart on Sun Feb 26 11:41:33 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Reliable Statistics's documentation!
==================================================
**relistats** is a Python library for computing reliable
statistics, such as reliability, confidence, and assurance as well as 
tolerance and assurance intervals. 

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   background
   usage
   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
